module.exports = defineTest({
	description: 'supports format aliases',
	command: 'rollup --config'
});
